==> nextcloud-14.0.13.zip: nextcloud/apps/twofactor_backupcodes/l10n/es.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Ha ocurrido un error mientras se generaban los códigos de respaldo.",
    "{name} backup codes" : "Códigos de respaldo {name}",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Estos son sus códigos de respaldo. Por favor guardelos y/o imprimalos ya que no podrá obtenerlos de nuevo.",
    "Save backup codes" : "Guardar códigos de respaldo",
    "Print backup codes" : "Imprimir códigos de respaldo",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Se han generado códigos de respaldo. Se han usado {used} de {total} códigos.",
    "Regenerate backup codes" : "Regenerar códigos de respaldo",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si regenera los códigos de respaldo, automáticamente invalidarás los antiguos.",
    "Generate backup codes" : "Generar códigos de respaldo",
    "You created two-factor backup codes for your account" : "Has creado códigos de respaldo para la verificación en dos pasos de tu cuenta",
    "Second-factor backup codes" : "Códigos de respaldo para verificación en dos pasos",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Has habilitado la verificación en dos pasos pero no has generado aún los códigos de respaldo. Asegúrate de hacerlo para usarlos en caso de pérdida de acceso del segundo paso",
    "Backup code" : "Código de respaldo",
    "Use backup code" : "Usar código de respaldo",
    "Two factor backup codes" : "Códigos de respaldo de la verificación en dos pasos",
    "A two-factor auth backup codes provider" : "Un proveedor de códigos respaldo para verificación en dos pasos",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Usa uno de los códigos de respaldo que guardaste cuando activaste la verificación en dos pasos.",
    "Submit" : "Enviar",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Se han generado los códigos de respaldo. Estás usando {{used}} de {{total}}.",
    "Nextcloud backup codes" : "Códigos de respaldo de Nextcloud",
    "activated" : "activado",
    "updated" : "actualizado",
    "mounted" : "montado",
    "deactivated" : "desactivado",
    "beforeCreate" : "beforeCreate",
    "created" : "creado",
    "beforeUpdate" : "beforeUpdate",
    "beforeDestroy" : "beforeDestroy",
    "destroyed" : "destruido",
    "beforeMount" : "beforeMount"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.0.zip: nextcloud/apps/twofactor_backupcodes/l10n/es.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Ha ocurrido un error mientras se generaban los códigos de respaldo.",
    "{name} backup codes" : "Códigos de respaldo {name}",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Estos son sus códigos de respaldo. Por favor guardelos y/o imprimalos ya que no podrá obtenerlos de nuevo.",
    "Save backup codes" : "Guardar códigos de respaldo",
    "Print backup codes" : "Imprimir códigos de respaldo",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Se han generado códigos de respaldo. Se han usado {used} de {total} códigos.",
    "Regenerate backup codes" : "Regenerar códigos de respaldo",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si regenera los códigos de respaldo, automáticamente invalidarás los antiguos.",
    "Generate backup codes" : "Generar códigos de respaldo",
    "You created two-factor backup codes for your account" : "Has creado códigos de respaldo para la verificación en dos pasos de tu cuenta",
    "Second-factor backup codes" : "Códigos de respaldo para verificación en dos pasos",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Has habilitado la verificación en dos pasos pero no has generado aún los códigos de respaldo. Asegúrate de hacerlo para acceder a tu cuenta en caso de pérdida del segundo paso",
    "Backup code" : "Código de respaldo",
    "Use backup code" : "Usar código de respaldo",
    "Two factor backup codes" : "Códigos de respaldo de la verificación en dos pasos",
    "A two-factor auth backup codes provider" : "Un proveedor de códigos respaldo para verificación en dos pasos",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Usa uno de los códigos de respaldo que guardaste cuando activaste la verificación en dos pasos.",
    "Submit" : "Enviar",
    "activated" : "activado",
    "updated" : "actualizado",
    "mounted" : "montado",
    "deactivated" : "desactivado",
    "beforeCreate" : "beforeCreate",
    "created" : "creado",
    "beforeUpdate" : "beforeUpdate",
    "beforeDestroy" : "beforeDestroy",
    "destroyed" : "destruido",
    "beforeMount" : "beforeMount",
    "Nextcloud backup codes" : "Códigos de respaldo de Nextcloud",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Has habilitado la verificación en dos pasos pero no has generado aún los códigos de respaldo. Asegúrate de hacerlo para usarlos en caso de pérdida de acceso del segundo paso"
},
"nplurals=2; plural=(n != 1);");
